@@ -1,5 +1,5 @@
 <?php
-Settings::register ( "google_maps_marker", "Am Flaschendreherkamp 12" );
+Settings::register ( "google_maps_marker", "Bohlweg 1, Braunschweig" );
 
 Settings::register ( "google_maps_zoom_level", "12" );
 Settings::register ( "google_maps_api_key", "InsertYourKeyHere" );
\ No newline at end of file
